DateDataModel class

Constructors

DateDataModel({required DateTime dateServerType, required int timeStamp, required String showDateStr})

Properties

dateServerType ↔ DateTime
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showDateStr ↔ String
getter/setter pair
timeStamp ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited