TimeDataModel class

Constructors

TimeDataModel({required String displayTime, required int hour, required int minute})

Properties

displayTime ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hour ↔ int
getter/setter pair
minute ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited