GSFieldModel class abstract

Implementers

Constructors

GSFieldModel({GSFieldTypeEnum? type, required String tag, bool? showTitle, String? title, String? errorMessage, String? helpMessage, Widget? prefixWidget, Widget? postfixWidget, bool? required, dynamic value, RegExp? validateRegEx, int? weight, FocusNode? focusNode, FocusNode? nextFocusNode, VoidCallback? onTap, GSFieldStatusEnum? status, bool? enableReadOnly})

Properties

enableReadOnly ↔ bool?
getter/setter pair
errorMessage ↔ String?
getter/setter pair
focusNode ↔ FocusNode?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
helpMessage ↔ String?
getter/setter pair
nextFocusNode ↔ FocusNode?
getter/setter pair
onTap ↔ VoidCallback?
getter/setter pair
postfixWidget ↔ Widget?
getter/setter pair
prefixWidget ↔ Widget?
getter/setter pair
required ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showTitle ↔ bool?
getter/setter pair
status ↔ GSFieldStatusEnum
getter/setter pair
tag ↔ String
getter/setter pair
title ↔ String?
getter/setter pair
type ↔ GSFieldTypeEnum?
getter/setter pair
validateRegEx ↔ RegExp?
getter/setter pair
value ↔ dynamic
getter/setter pair
weight ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited