GSFormUtils class

Constructors

GSFormUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

checkIfDarkModeEnabled(BuildContext context) → bool
getFieldDecoration(GSFormStyle style, GSFieldStatusEnum? status, {double? borderWidth = 1.0}) → Decoration
isDirectionRTL(BuildContext context) → bool
pickImage(ImageSource imageSource) → Future<File?>
showImagePickerBottomSheet(BuildContext context, void callback(File image), {String? galleryName = 'Gallery', String? cameraName = 'Camera', String? cameraAssets, String? galleryAssets}) → dynamic